aboutsummaryrefslogtreecommitdiff
path: root/discord/channel.py
diff options
context:
space:
mode:
authorNadir Chowdhury <[email protected]>2021-02-23 08:36:37 +0000
committerGitHub <[email protected]>2021-02-23 03:36:37 -0500
commit427e387a2f487cf27d4a7ed5b49cc4c4bcae58ed (patch)
treea19af8a9417958a732452c2cb31a2075f5e9ab97 /discord/channel.py
parent[commands] Allow relative paths when handling extensions (diff)
downloaddiscord.py-427e387a2f487cf27d4a7ed5b49cc4c4bcae58ed.tar.xz
discord.py-427e387a2f487cf27d4a7ed5b49cc4c4bcae58ed.zip
Deprecate non-bot methods
Diffstat (limited to 'discord/channel.py')
-rw-r--r--discord/channel.py11
1 files changed, 10 insertions, 1 deletions
diff --git a/discord/channel.py b/discord/channel.py
index db4b566d..7a5b9548 100644
--- a/discord/channel.py
+++ b/discord/channel.py
@@ -347,7 +347,7 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
bulk: :class:`bool`
If ``True``, use bulk delete. Setting this to ``False`` is useful for mass-deleting
a bot's own messages without :attr:`Permissions.manage_messages`. When ``True``, will
fall back to single delete if current account is a user bot, or if messages are
older than two weeks.
Raises
@@ -1274,6 +1274,7 @@ class GroupChannel(discord.abc.Messageable, Hashable):
return base
+ @utils.deprecated()
async def add_recipients(self, *recipients):
r"""|coro|
@@ -1284,6 +1285,8 @@ class GroupChannel(discord.abc.Messageable, Hashable):
add a recipient to the group, you must have a relationship
with the user of type :attr:`RelationshipType.friend`.
+ .. deprecated:: 1.7
+
Parameters
-----------
\*recipients: :class:`User`
@@ -1301,11 +1304,14 @@ class GroupChannel(discord.abc.Messageable, Hashable):
for recipient in recipients:
await req(self.id, recipient.id)
+ @utils.deprecated()
async def remove_recipients(self, *recipients):
r"""|coro|
Removes recipients from this group.
+ .. deprecated:: 1.7
+
Parameters
-----------
\*recipients: :class:`User`
@@ -1323,11 +1329,14 @@ class GroupChannel(discord.abc.Messageable, Hashable):
for recipient in recipients:
await req(self.id, recipient.id)
+ @utils.deprecated()
async def edit(self, **fields):
"""|coro|
Edits the group.
+ .. deprecated:: 1.7
+
Parameters
-----------
name: Optional[:class:`str`]
@@ -347,7 +347,7 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
If ``True``, use bulk delete. Setting this to ``False`` is useful for mass-deleting
a bot's own messages without :attr:`Permissions.manage_messages`. When ``True``, will
- fall back to single delete if current account is a user bot, or if messages are
+ fall back to single delete if current account is a user bot (now deprecated), or if messages are
older than two weeks.
Raises